/*
 Copyright (c) 2007 Kathryn Huxtable

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 $Id: SampleValidatorTest.java 495 2007-03-31 14:55:20Z huxtable $
 */
package org.kathrynhuxtable.middleware.shibshim.util.properties;

import java.util.HashMap;
import java.util.Map;

import junit.framework.TestCase;

/**
 * Test the SampleValidator class.
 */
public class PropertiesBundleTest extends TestCase {

    public void testSample() {
        // First try with an invalid file.
        try {
            PropertiesBundle.init("/invalid.properties");
            fail("Failed to throw PropertiesBundleException for invalid file");
        } catch (PropertiesBundleException e1) {
            assertTrue(true);
        }

        // Next try with an unreadable file.
        if (false) {
            try {
                PropertiesBundle.init("/unreadable.properties");
                fail("Failed to throw PropertiesBundleException for unreadable file");
            } catch (PropertiesBundleException e1) {
                assertTrue(true);
            }
        }

        // Now load the good properties file.
        try {
            PropertiesBundle.init("/test.properties");
        } catch (PropertiesBundleException e) {
            fail("Got PropertiesBundleException reading good properties file");
        }

        try {
            assertEquals("https://myshim.example.edu/shibshim/ACS", PropertiesBundle.getString("foo", "acsUrl"));
        } catch (PropertiesBundleException e) {
            fail("Got PropertiesBundleException reading good properties file");
        }

        try {
            assertEquals(120, PropertiesBundle.getInteger("foo", "timeout"));
        } catch (PropertiesBundleException e) {
            fail("Got PropertiesBundleException getting timeout");
        }

        try {
            assertEquals(10, PropertiesBundle.getInteger("foo", "bogusInt", 10));
        } catch (PropertiesBundleException e) {
            fail("Got PropertiesBundleException getting bogusInt");
        }

        try {
            assertEquals("junk", PropertiesBundle.getString("foo", "badPropertyName", "junk"));
        } catch (PropertiesBundleException e) {
            fail("Got PropertiesBundleException getting bad property name with default value");
        }

        try {
            PropertiesBundle.getString("foo", "badPropertyName");
            fail("Failed to get PropertiesBundleException on bad property name with no default value");
        } catch (PropertiesBundleException e) {
            assertTrue(true);
        }

        Map attributeMap = null;
        try {
            attributeMap = PropertiesBundle.getMap("foo", "attributeMap.");
        } catch (PropertiesBundleException e) {
            fail("Got PropertiesBundleException getting attribute map");
        }
        assertEquals(3, attributeMap.size());

        assertEquals("shib-ismemberof", attributeMap.get("shib-em-ismemberof"));
        assertEquals("shib-affiliation", attributeMap.get("shib-ep-affiliation"));
        assertEquals("shib-edupersonprincipalname", attributeMap.get("shib-ep-edupersonprincipalname"));

        Map bogusMap = null;
        Map defaultMap = new HashMap();
        defaultMap.put("test", "bogus");
        try {
            bogusMap = PropertiesBundle.getMap("foo", "bogusMap.", defaultMap);
        } catch (PropertiesBundleException e) {
            fail("Got PropertiesBundleException getting bogus map");
        }
        assertEquals(1, bogusMap.size());

        assertEquals("bogus", bogusMap.get("test"));

        Map bogus2Map = null;
        try {
            bogus2Map = PropertiesBundle.getMap("foo", "bogus2Map.");
            fail("Failed to throw PropertiesBundleException getting bogus2 map");
        } catch (PropertiesBundleException e) {
            assertNull(bogus2Map);
        }
    }
}
